@@ -56,47 +56,48 @@ void MainWindow::setupActions()
     KGameStandardAction::quit(this, &MainWindow::close, actionCollection());
     
     QAction* action;
-    action = new QAction(i18n("&Single Player"), this);
+    action = new QAction(i18nc("@action", "&Single Player"), this);
     action->setIcon(QIcon::fromTheme( QLatin1String( SimpleMenu::iconLocal)));
     actionCollection()->addAction(QStringLiteral("game_local"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::localGame);
-    action = new QAction(i18n("&Host Game..."), this);
+    action = new QAction(i18nc("@action", "&Host Game…"), this);
     action->setIcon(QIcon::fromTheme( QLatin1String( SimpleMenu::iconServer)));
     actionCollection()->addAction(QStringLiteral("game_create_server"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::createServer);
-    action = new QAction(i18n("&Connect to Game..."), this);
+    action = new QAction(i18nc("@action", "&Connect to Game…"), this);
     action->setIcon(QIcon::fromTheme( QLatin1String( SimpleMenu::iconClient))),
     actionCollection()->addAction(QStringLiteral("game_create_client"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::createClient);
     // settings
-    action = new QAction(i18n("Change &Nickname..."), this);
+    action = new QAction(i18nc("@action", "Change &Nickname…"), this);
     actionCollection()->addAction(QStringLiteral("options_nickname"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::changeNick);
-    action = new KToggleAction(i18n("&Play Sounds"), this);
+    action = new KToggleAction(QIcon::fromTheme(QStringLiteral("speaker")),
+                               i18nc("@option:check", "Play Sounds"), this);
     action->setChecked(Settings::enableSounds());
     actionCollection()->addAction(QStringLiteral("options_sounds"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleSounds);
     // This action will be disabled when a game is being run
-    action = new KToggleAction(i18n("&Adjacent Ships"), this);
+    action = new KToggleAction(i18nc("@option:check", "&Adjacent Ships"), this);
     action->setChecked(Settings::adjacentShips());
     actionCollection()->addAction(QStringLiteral("options_adjacent"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleAdjacent);
     // This action will be disabled when a game is being run
-    action = new KToggleAction(i18n("&Multiple Ships"), this);
+    action = new KToggleAction(i18nc("@option:check", "&Multiple Ships"), this);
     action->setChecked(Settings::severalShips());
     actionCollection()->addAction(QStringLiteral("options_multiple_ships"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleMultiple);
     // config end of game message
-    action = new KToggleAction(i18n("Show End-of-Game Message"), this);
+    action = new KToggleAction(i18nc("@option:check", "Show End-of-Game Message"), this);
     action->setChecked(true);
     actionCollection()->addAction(QStringLiteral("options_show_endgame_message"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleEndOfGameMessage);
     // actions for grid
-    action = new KToggleAction(i18n("Show &Left Grid"), this);
+    action = new KToggleAction(i18nc("@option:check", "Show &Left Grid"), this);
     action->setChecked(true);
     actionCollection()->addAction(QStringLiteral("options_showleftgrid"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleLeftGrid);
-    action = new KToggleAction(i18n("Show &Right Grid"), this);
+    action = new KToggleAction(i18nc("@option:check", "Show &Right Grid"), this);
     action->setChecked(true);
     actionCollection()->addAction(QStringLiteral("options_showrightgrid"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleRightGrid);
