@@ -47,7 +47,7 @@ NetworkDialog::NetworkDialog(bool client, QWidget* parent, const QUrl* url)
     QVBoxLayout* mainLayout = new QVBoxLayout;
 
     // feedback
-    m_feedback = new QLabel(QLatin1String(""), this);
+    m_feedback = new QLabel(this);
     m_feedback->setAlignment(Qt::AlignHCenter);
     {
         QFont font = m_feedback->font();
@@ -113,7 +113,7 @@ NetworkDialog::NetworkDialog(bool client, QWidget* parent, const QUrl* url)
         mainLayout->addWidget(frame);
         frame->setVisible(false);
         
-        QPushButton* sw=new QPushButton(i18n("&Enter server address manually"), main);
+        auto* sw = new QPushButton(i18nc("@action:button", "&Enter Server Address Manually"), main);
         sw->setCheckable(true);
         connect(sw, &QPushButton::toggled, frame, &QWidget::setVisible);
         connect(sw, &QPushButton::toggled, m_games, &KComboBox::setDisabled);
@@ -145,7 +145,7 @@ NetworkDialog::NetworkDialog(bool client, QWidget* parent, const QUrl* url)
     topLayout->addWidget(main);
     topLayout->addWidget(buttonBox);
 
-    setWindowTitle(i18n("Network Parameters"));
+    setWindowTitle(i18nc("@title:window", "Network Parameters"));
     
     connect(this, &NetworkDialog::accepted, this, &NetworkDialog::savePreferences);
     
@@ -207,14 +207,14 @@ void NetworkDialog::slotOkClicked()
         m_feedback->show();
        
         if (m_client) {
-            m_feedback->setText(i18n("Connecting to remote host..."));
+            m_feedback->setText(i18n("Connecting to remote host…"));
             m_socket = new QTcpSocket;
             connect(m_socket, &QTcpSocket::connected, this, &NetworkDialog::clientOK);
             connect(m_socket, &QTcpSocket::errorOccurred, this, &NetworkDialog::clientError);
             m_socket->connectToHost(m_hostname->text(), m_port->value());
         }
         else {
-            m_feedback->setText(i18n("Waiting for an incoming connection..."));        
+            m_feedback->setText(i18n("Waiting for an incoming connection…"));
             QTcpServer* server = new QTcpServer;
             connect(server, &QTcpServer::newConnection, this, &NetworkDialog::serverOK);
             m_publisher=new KDNSSD::PublicService(nickname(), QStringLiteral("_kbattleship._tcp"), m_port->value());
